summaryrefslogtreecommitdiffstatshomepage
path: root/src/emu/cpu/m68000/m68000.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/emu/cpu/m68000/m68000.h')
-rw-r--r--src/emu/cpu/m68000/m68000.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/emu/cpu/m68000/m68000.h b/src/emu/cpu/m68000/m68000.h
index 34676200026..d9b9200cee6 100644
--- a/src/emu/cpu/m68000/m68000.h
+++ b/src/emu/cpu/m68000/m68000.h
@@ -356,8 +356,8 @@ public:
UINT16 mmu_tmp_buserror_rw; /* temporary hack: (first) bus error rw */
UINT32 ic_address[M68K_IC_SIZE]; /* instruction cache address data */
- UINT16 ic_data[M68K_IC_SIZE]; /* instruction cache content data */
-
+ UINT32 ic_data[M68K_IC_SIZE]; /* instruction cache content data */
+ bool ic_valid[M68K_IC_SIZE]; /* instruction cache valid flags */